import { Component, EventEmitter, Input, Output } from "@angular/core";
import { EventType, ScheduledEvent } from "../../../../../../models/data/scheduled_events.model";
import { TranslateService } from "@ngx-translate/core";
import { FormBuilder, FormControl, Validators } from "@angular/forms";

@Component({
  selector: "app-edit-scheduled-event-dialog",
  templateUrl: "./edit-scheduled-event-dialog.component.html",
  styleUrls: ["./edit-scheduled-event-dialog.component.scss"]
})
export class EditScheduledEventDialogComponent {
  @Input() event?: ScheduledEvent;
  @Output() save = new EventEmitter<ScheduledEvent>();

  get visible() {
    return this.event != undefined;
  }

  set visible(val: boolean) {
    if (!val) {
      this.event = undefined;
    }
    this.visible = val;
  }

  get header() {
    if (this.event && this.event.createdAt === "" && this.event.modifiedAt === "") {
      return this.translate.instant("view.server.scheduled_events.edit_dialog.add_header");
    } else {
      return this.translate.instant("view.server.scheduled_events.edit_dialog.edit_header");
    }
  }

  public activeIndex: number = 0;
  public inputForm = this.fb.group({
    id: new FormControl<number | undefined>(this.event?.id),
    interval: new FormControl<string | undefined>(this.event?.interval, [Validators.required]),
    entityType: new FormControl<number | undefined>(this.event?.entityType, [Validators.required]),
    channelId: new FormControl<string | undefined>(this.event?.channelId, this.event?.entityType == EventType.voice || this.event?.entityType == EventType.stageInstance ? [Validators.required] : []),
    location: new FormControl<string | undefined>(this.event?.location, this.event?.entityType == EventType.external ? [Validators.required] : []),
    name: new FormControl<string | undefined>(this.event?.name, [Validators.required]),
    startTime: new FormControl<string | undefined>(this.event?.startTime, [Validators.required]),
    endTime: new FormControl<string | undefined>(this.event?.endTime),
    description: new FormControl<string | undefined>(this.event?.description)
  });

  constructor(
    private translate: TranslateService,
    private fb: FormBuilder
  ) {
  }

  public saveEvent() {
    this.save.emit(this.event);
  }

  public next() {
    this.activeIndex++;
  }

  public back() {
    this.activeIndex--;
  }

  protected readonly EventType = {
    stage: EventType.stageInstance,
    voice: EventType.voice,
    somewhere_else: EventType.external
  };
}
